Indsæt tabel

Indsæt tabel | TOC

Trykker man på indsæt tabel knappen åbnes det vindue, som du kan se herunder. I dette vindue kan du oprette nye tabeller.
Feltbeskrivelser:

Kolonner | Antal kolonner i tabellen.
Rækker | Antal rækker i tabellen.
Cellemargin | Tabellens cellemargin.
Indvendig margin | Indvendig margin i cellerne.
Justering | Tabellens justering.
Kant | Kantbredden i tabellen.
Bredde | Tabellens bredde i pixels.
Højde | Tabellens højde i pixels.
Klasse | Style eller stylesheet klasse for tabellen.

Tilbage til: Indholdsfortegnelse | Top